@@ -3,7 +3,7 @@
 """\
 Core functions to execute sub-commands called from command line.
 """
-
+import re
 import sys
 import os
 
@@ -131,7 +131,17 @@ def main(argv):
         }
         execp = execp_key[args.tool_set]
         path = args.tool_path
-        args.func(execp, path, **get_params(args,))
+        if args.tool_set == "sharp":
+            hashtag_param = {
+                "secret": os.path.expanduser("~/.cromwell/credentials.json"),
+                "labels": os.path.join("config", args.jobs),
+                "inputs": os.path.join(
+                    "config", re.sub("labels.json$", "inputs.json", args.jobs)
+                ),
+            }
+            args.func(execp, path, hashtag_param, **get_params(args,))
+        else:
+            args.func(execp, path, **get_params(args,))
     else:
         args.func(args)
 
